package com.example.myapplication

import android.app.Dialog
import android.os.Bundle
import android.widget.Button
import android.widget.EditText
import android.widget.Toast
import androidx.appcompat.app.AlertDialog
import androidx.fragment.app.DialogFragment

class AddRecipeDialogFragment(
    private val onRecipeAdded: (Recipe) -> Unit // Callback für das Hinzufügen eines Rezepts
) : DialogFragment() {

    override fun onCreateDialog(savedInstanceState: Bundle?): Dialog {
        // Dialog-Builder initialisieren
        val builder = AlertDialog.Builder(requireContext())

        // Dialog-Layout inflaten
        val dialogView = requireActivity().layoutInflater.inflate(R.layout.dialog_add_recipe, null)

        // UI-Elemente aus dem Layout referenzieren
        val nameEditText = dialogView.findViewById<EditText>(R.id.recipeNameInput)
        val ingredientsEditText = dialogView.findViewById<EditText>(R.id.recipeIngredientsInput)
        val instructionsEditText = dialogView.findViewById<EditText>(R.id.recipeInstructionsInput)
        val addButton = dialogView.findViewById<Button>(R.id.saveRecipeButton)

        // Dialog-Layout setzen
        builder.setView(dialogView)
        val dialog = builder.create()

        // Hinzufügen-Button Logik
        addButton.setOnClickListener {
            val name = nameEditText.text.toString().trim()
            val ingredients = ingredientsEditText.text.toString().trim()
            val instructions = instructionsEditText.text.toString().trim()

            // Schritte aus den Anweisungen extrahieren
            val steps = instructions.split(",").map { it.trim() }.filter { it.isNotEmpty() }

            if (name.isNotEmpty() && ingredients.isNotEmpty() && instructions.isNotEmpty()) {
                // Neues Rezept erstellen und übergeben
                val newRecipe = Recipe(name, ingredients, instructions, steps)
                onRecipeAdded(newRecipe)
                dialog.dismiss()

                // Erfolgsmeldung
                Toast.makeText(requireContext(), "Rezept wurde erfolgreich gespeichert!", Toast.LENGTH_SHORT).show()
            } else {
                // Fehlerhinweis, wenn nicht alle Felder ausgefüllt wurden
                Toast.makeText(requireContext(), "Bitte füllen Sie alle Felder aus", Toast.LENGTH_SHORT).show()
            }
        }

        return dialog
    }
}
