package com.example.myapplication

import android.net.Uri
import android.os.Bundle
import android.widget.Button
import androidx.appcompat.app.AppCompatActivity
import android.widget.TextView
import android.widget.ImageView
import android.content.Intent

class RecipeDetailActivity : AppCompatActivity() {
    override fun onCreate(savedInstanceState: Bundle?) {
        super.onCreate(savedInstanceState)

        // Theme basierend auf gespeicherten Einstellungen setzen
        val preferences = getSharedPreferences("appSettings", MODE_PRIVATE)
        val savedColorOption = preferences.getInt("colorOption", 1)
        setTheme(if (savedColorOption == 1) R.style.Theme_myapplication else R.style.Theme_MyApp_BlueTheme)

        setContentView(R.layout.activity_recipe_detail)

        // Rezeptdaten aus Intent abrufen
        val recipe = intent.getParcelableExtra<Recipe>("RECIPE")

        // UI-Elemente initialisieren
        val recipeNameTextView = findViewById<TextView>(R.id.recipeTitle)
        val recipeImageView = findViewById<ImageView>(R.id.recipeImage)
        val recipeIngredientsTextView = findViewById<TextView>(R.id.recipeIngredients)
        val recipeInstructionsTextView = findViewById<TextView>(R.id.recipeInstructions)
        val startCookingButton = findViewById<Button>(R.id.startCookingButton)

        // Rezeptinformationen anzeigen
        recipe?.let {
            recipeNameTextView.text = it.name
            recipeIngredientsTextView.text = "Zutaten: ${it.ingredients}"
            recipeInstructionsTextView.text = "Anleitung: ${it.instructions}"

            if (!it.imageUri.isNullOrEmpty()) {
                recipeImageView.setImageURI(Uri.parse(it.imageUri))
            } else {
                recipeImageView.setImageResource(R.drawable.platzhalter) // Platzhalterbild
            }
        }

        // Klick-Listener für den "Kochen starten"-Button
        startCookingButton.setOnClickListener {
            val intent = Intent(this, CookingModeActivity::class.java)
            intent.putExtra("RECIPE", recipe)
            startActivity(intent)
        }
    }
}
